'use strict';
Object.defineProperty(exports, "__esModule", { value: true });
const node_fetch_1 = require("node-fetch");
const cheerio = require("cheerio");
const util_1 = require("./util");
/**
 *  Fetches meta data of a given website url
 * @param url | the website url to fetch the metadata from
 */
const fetchMetaData = async (url, _options) => {
    var _a, _b;
    try {
        const urlString = url.trim();
        // Options validation
        if (!_options || typeof _options !== 'object') {
            _options = {};
        }
        const options = {
            userAgent: (_a = _options.userAgent) !== null && _a !== void 0 ? _a : 'meta-fetch',
            fromEmail: (_b = _options.fromEmail) !== null && _b !== void 0 ? _b : 'metafetch@email.com'
        };
        const requestOptions = {
            method: 'GET',
            headers: {
                'User-Agent': options.userAgent,
                From: options.fromEmail
            }
        };
        const response = await node_fetch_1.default(urlString, requestOptions);
        const content = await response.text();
        // Load html to cheerio
        const $ = cheerio.load(content);
        const head = $('head');
        // Basic site meta-data
        const basicMeta = () => {
            const website = response.url;
            const title = head.find('title').text();
            const desc = head.find('meta[name=description]').attr('content');
            return {
                website,
                title,
                description: desc
            };
        };
        // Open graph basic
        const fetchMeta = () => {
            const openGraphsArray = head.find('meta[property]');
            const openGraphs = {};
            openGraphsArray.each((_, element) => {
                const property = $(element)
                    .attr('property');
                const content = $(element).attr('content');
                if (!property.includes('twitter')) {
                    openGraphs[property] = content;
                }
            });
            return openGraphs;
        };
        // Open graph social
        const fetchMetaSocial = () => {
            const openGraphsArray = head.find('meta[name]');
            const socials = {};
            openGraphsArray.each((_, element) => {
                const property = $(element).attr('name');
                const content = $(element).attr('content');
                if (property.includes('twitter')) {
                    socials[property] = content;
                }
            });
            return socials;
        };
        // Favicons
        const fetchFavicons = () => {
            const faviconArray = head.find('link[rel]');
            const favicons = [];
            faviconArray.each((_, element) => {
                const href = $(element).attr('href');
                if (href.includes('shortcut icon') || href.includes('icon') || href.includes('apple-touch-startup-image') || href.includes('apple-touch-icon')) {
                    const validUri = util_1.createValidUri(response.url, href);
                    favicons.push(validUri);
                }
            });
            return favicons;
        };
        // Meta-data
        const basicMetaData = basicMeta();
        const openGraphs = fetchMeta();
        const openGraph_social = fetchMetaSocial();
        const favicons = fetchFavicons();
        const metaData = {
            basic_metadata: basicMetaData,
            opengraph: openGraphs,
            opengraph_social: openGraph_social,
            favicons
        };
        return metaData;
    }
    catch (error) {
        console.error(error);
    }
};
exports.default = fetchMetaData;
// For CommonJS default export support
module.exports = fetchMetaData;
module.exports.default = fetchMetaData;
